# coding=utf-8
from unittest import TestCase
from earthdiagnostics.cmormanager import CMORManager
from earthdiagnostics.modelingrealm import ModelingRealms
from mock import Mock
import tempfile
import os
import shutil


class TestCMORManager(TestCase):

    def setUp(self):
        self.config = Mock()
        self.config.data_convention = 'specs'
        self.config.experiment.expid = 'expid'
        self.config.experiment.model = 'model'
        self.config.experiment.atmos_timestep = 6
        self.config.experiment.ocean_timestep = 6

        self.tmp_dir = tempfile.mkdtemp()
        os.mkdir(os.path.join(self.tmp_dir, self.config.experiment.expid))
        self.config.data_dir = self.tmp_dir

    def tearDown(self):
        shutil.rmtree(self.tmp_dir)

    def test_find_data(self):
        cmor_manager = CMORManager(self.config)
        self.assertEqual(cmor_manager.cmor_path, os.path.join(self.tmp_dir, 'expid'))

    def test_find_data_fail(self):
        os.rmdir(os.path.join(self.tmp_dir, self.config.experiment.expid))
        with self.assertRaises(Exception):
            CMORManager(self.config)

    def test_find_data_with_model(self):
        os.makedirs(os.path.join(self.tmp_dir, 'model', self.config.experiment.expid))
        os.rmdir(os.path.join(self.tmp_dir, self.config.experiment.expid))
        cmor_manager = CMORManager(self.config)
        self.assertEqual(cmor_manager.cmor_path, os.path.join(self.tmp_dir, 'model', 'expid'))

    def test_get_varfolder(self):
        cmor_manager = CMORManager(self.config)
        self.assertEqual(cmor_manager.get_varfolder(ModelingRealms.ocean, 'var'),
                         'var_f6h')

